@@ -7,10 +7,10 @@
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
@@ -18,13 +18,13 @@
  * Boston, MA  02110-1301  USA
  */
 
-#ifndef __GPHOTO2_PORT_RESULT_H__
-#define __GPHOTO2_PORT_RESULT_H__
+#ifndef LIBGPHOTO2_GPHOTO2_PORT_RESULT_H
+#define LIBGPHOTO2_GPHOTO2_PORT_RESULT_H
 
 /* Return values. gphoto2-port should only return values from 0 to -99 */
 /**
  * \brief Everything is OK
- * 
+ *
  * Note that this is also the value 0, and every error is negative (lower).
  */
 #define GP_OK                            0
@@ -75,7 +75,7 @@
 #define GP_ERROR_IO_SUPPORTED_USB       -21
 
 /**
- * \brief Error initialising I/O
+ * \brief Error initializing I/O
  */
 #define GP_ERROR_IO_INIT                -31
 /**
@@ -129,5 +129,5 @@ const char *gp_port_result_as_string (int result);
 }
 #endif /* __cplusplus */
 
-#endif /* __GPHOTO2_PORT_RESULT_H__ */
+#endif /* !defined(LIBGPHOTO2_GPHOTO2_PORT_RESULT_H) */
 
