@@ -1,4 +1,4 @@
-/** \file 
+/** \file
  *
  * \author Copyright 2001 Lutz Mueller <lutz@users.sf.net>
  *
@@ -9,29 +9,25 @@
  * version 2 of the License, or (at your option) any later version.
  *
  * \par
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * \par
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
-#ifndef __GPHOTO2_PORT_H__
-#define __GPHOTO2_PORT_H__
+#ifndef LIBGPHOTO2_GPHOTO2_PORT_H
+#define LIBGPHOTO2_GPHOTO2_PORT_H
 
 #include <gphoto2/gphoto2-port-info-list.h>
 
 /* For portability */
 #include <gphoto2/gphoto2-port-portability.h>
-#ifdef OS2
-#include <gphoto2/gphoto2-port-portability-os2.h>
-#include <os2.h>
-#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -47,7 +43,7 @@ extern "C" {
 
 /**
  * \brief Serial parity
- * 
+ *
  * Parity of the serial port.
  */
 typedef enum _GPPortSerialParity
@@ -58,7 +54,7 @@ typedef enum _GPPortSerialParity
 } GPPortSerialParity;
 
 /** \brief Maximum length of receive buffer */
-#define GP_PORT_MAX_BUF_LEN 4096             
+#define GP_PORT_MAX_BUF_LEN 4096
 
 /**
  * \brief Port settings for serial ports.
@@ -67,7 +63,7 @@ typedef struct _GPPortSettingsSerial {
 	char port[128];		/**< The portname (/dev/ttyX)*/
 	int speed;		/**< The baudrate of the device. */
 	int bits;		/**< How many bits data. */
-	GPPortSerialParity parity;	/**< parity data, see GP_PORT_SERIAL_PARITY_ 
+	GPPortSerialParity parity;	/**< parity data, see GP_PORT_SERIAL_PARITY_
 				  defines */
 	int stopbits;		/**< How many stop bits are used. */
 } GPPortSettingsSerial;
@@ -86,17 +82,24 @@ typedef struct _GPPortSettingsUSB {
 	int maxpacketsize;	/**< \brief Maximum USB packetsize of the IN endpoint. (r/o) */
 
 	/* must be last to avoid binary incompatibility.
-	 * luckily we just need to make sure this struct does not 
+	 * luckily we just need to make sure this struct does not
 	 * get larger than _GPPortSettingsSerial. */
 	char port[64];		/**< \brief USB Portname. Specific to lowlevel USB. */
 } GPPortSettingsUSB;
 
 /**
- * \brief Port settings for the local disk (directories) port.
+ * \brief Port settings for USB mass storage direct IO ports.
  */
-typedef struct _GPPortSettingsDisk {
-	char mountpoint[128];	/**< \brief Path in the UNIX fs which corresponds to gphoto2 / */
-} GPPortSettingsDisk;
+typedef struct _GPPortSettingsUsbDiskDirect {
+	char path[128];		/**< /brief The ports device node path (/dev/sdX)*/
+} GPPortSettingsUsbDiskDirect;
+
+/**
+ * \brief Port settings for USB Mass Storage raw SCSI ports.
+ */
+typedef struct _GPPortSettingsUsbScsi {
+	char path[128];		/**< /brief The ports device node path (/dev/sg#)*/
+} GPPortSettingsUsbScsi;
 
 /**
  * \brief Union of port settings.
@@ -107,7 +110,8 @@ typedef struct _GPPortSettingsDisk {
 typedef union _GPPortSettings {
 	GPPortSettingsSerial serial;	/**< \brief Serial specific settings */
 	GPPortSettingsUSB usb;		/**< \brief USB specific settings */
-	GPPortSettingsDisk disk;	/**< \brief Disk port specific settings */
+	GPPortSettingsUsbDiskDirect usbdiskdirect; /**< \brief usb disk direct port specific settings */
+	GPPortSettingsUsbScsi usbscsi;	/**< \brief usb scsi port specific settings */
 } GPPortSettings;
 
 enum {
@@ -148,12 +152,14 @@ typedef struct _GPPort {
 int gp_port_new         (GPPort **port);
 int gp_port_free        (GPPort *port);
 
-int gp_port_set_info    (GPPort *port, GPPortInfo  info);
+int gp_port_set_info    (GPPort *port, GPPortInfo info);
 int gp_port_get_info    (GPPort *port, GPPortInfo *info);
 
 int gp_port_open        (GPPort *port);
 int gp_port_close       (GPPort *port);
 
+int gp_port_reset       (GPPort *port);
+
 int gp_port_write       (GPPort *port, const char *data, int size);
 int gp_port_read        (GPPort *port,       char *data, int size);
 int gp_port_check_int   (GPPort *port,       char *data, int size);
@@ -167,7 +173,7 @@ int gp_port_get_settings (GPPort *port, GPPortSettings *settings);
 
 /**
  * \brief Serial pins.
- * 
+ *
  * A number of serial pins to trigger and pull. This is necessary
  * for some devices that have more than just the regular 3 or 4 wires.
  */
@@ -182,7 +188,7 @@ typedef enum _GPPin {
 
 /**
  * \brief Level to pull specific lines.
- * 
+ *
  * The level on which to pull some of the serial lines.
  */
 typedef enum _GPLevel {
@@ -203,15 +209,22 @@ int gp_port_usb_msg_write   (GPPort *port, int request, int value,
 			     int index, char *bytes, int size);
 int gp_port_usb_msg_read    (GPPort *port, int request, int value,
 			     int index, char *bytes, int size);
-int gp_port_usb_msg_interface_write    (GPPort *port, int request, 
+int gp_port_usb_msg_interface_write    (GPPort *port, int request,
 			    int value, int index, char *bytes, int size);
-int gp_port_usb_msg_interface_read    (GPPort *port, int request, 
+int gp_port_usb_msg_interface_read    (GPPort *port, int request,
 			    int value, int index, char *bytes, int size);
-int gp_port_usb_msg_class_write    (GPPort *port, int request, 
+int gp_port_usb_msg_class_write    (GPPort *port, int request,
 			    int value, int index, char *bytes, int size);
-int gp_port_usb_msg_class_read    (GPPort *port, int request, 
+int gp_port_usb_msg_class_read    (GPPort *port, int request,
 			    int value, int index, char *bytes, int size);
 
+int gp_port_seek (GPPort *port, int offset, int whence);
+
+int gp_port_send_scsi_cmd (GPPort *port, int to_dev,
+				char *cmd, int cmd_size,
+				char *sense, int sense_size,
+				char *data, int data_size);
+
 /* Error reporting */
 int         gp_port_set_error (GPPort *port, const char *format, ...)
 #ifdef __GNUC__
@@ -232,6 +245,4 @@ typedef GPPortSettings gp_port_settings;
 }
 #endif /* __cplusplus */
 
-#endif /* __GPHOTO2_PORT_H__ */
-
-
+#endif /* !defined(LIBGPHOTO2_GPHOTO2_PORT_H) */
